@@ -1,9 +1,10 @@
 from django.contrib import admin
-from config.config import Config
+
+from config.config import JConfig
 # 引入用户平台
 from .models import *
 
-config = Config()
+config = JConfig()
 
 
 # Register your models here.
@@ -11,12 +12,10 @@ config = Config()
 
 class BaseInfoAdmin(admin.ModelAdmin):
     # fields = ('user_name', 'full_name', 'platform', 'platform_uid', 'phone', 'email', 'wechat', 'user_info')
-    fields = ('id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group',
-              'permission', 'register_time')
+    fields = ('id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'register_time')
     list_display = (
-        'id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'user_group',
-        'permission', 'register_time')
-    search_fields = ('user_name', 'full_name', 'nickname', 'phone', 'user_group__group')
+        'id', 'user_name', 'full_name', 'nickname', 'phone', 'email', 'wechat_openid', 'user_info', 'register_time')
+    search_fields = ('user_name', 'full_name', 'nickname', 'phone',)
     list_filter = []
     readonly_fields = ['id']
 
@@ -44,8 +43,8 @@ class DetailInfoAdmin(admin.ModelAdmin):
 
 
 class ExtendFieldAdmin(admin.ModelAdmin):
-    fields = ('id', 'field', 'field_index', 'description')
-    list_display = ('field', 'field_index', 'description')
+    fields = ('id', 'field', 'field_index', 'description', 'type', 'config', 'default', 'sort')
+    list_display = ('field', 'field_index', 'description', 'type', 'config', 'default', 'sort')
     readonly_fields = ['id']
 
 
@@ -79,24 +78,24 @@ class PlatformsToUsersAdmin(admin.ModelAdmin):
     readonly_fields = ['id']
 
 
-class PermissionAdmin(admin.ModelAdmin):
-    fields = ('permission_id', 'permission_name',)
-    list_display = ('permission_id', 'permission_name',)
+# class PermissionAdmin(admin.ModelAdmin):
+#     fields = ('permission_id', 'permission_name',)
+#     list_display = ('permission_id', 'permission_name',)
 
 
-class PermissionValueAdmin(admin.ModelAdmin):
-    fields = ('id', 'permission', 'module', 'feature', 'permission_value', 'type',
-              'relate_value', 'config', 'is_enable', 'is_system', 'is_ban', 'ban_view', 'ban_edit', 'ban_add',
-              'ban_delete',
-              'description')
-    list_display = ('permission', 'permission_value', 'type', 'is_system', 'is_ban',)
-    readonly_fields = ['id']
+# class PermissionValueAdmin(admin.ModelAdmin):
+#     fields = ('id', 'permission', 'module', 'feature', 'permission_value', 'type',
+#               'relate_value', 'config', 'is_enable', 'is_system', 'is_ban', 'ban_view', 'ban_edit', 'ban_add',
+#               'ban_delete',
+#               'description')
+#     list_display = ('permission', 'permission_value', 'type', 'is_system', 'is_ban',)
+#     readonly_fields = ['id']
 
 
-class GroupAdmin(admin.ModelAdmin):
-    fields = ('id', 'group', 'parent_group', 'description')
-    list_display = ('id', 'group', 'parent_group', 'description')
-    readonly_fields = ['id']
+# class GroupAdmin(admin.ModelAdmin):
+#     fields = ('id', 'group', 'parent_group', 'description')
+#     list_display = ('id', 'group', 'parent_group', 'description')
+#     readonly_fields = ['id']
 
 
 class ContactBookAdmin(admin.ModelAdmin):
@@ -119,6 +118,18 @@ class UserSsoToUserAdmin(admin.ModelAdmin):
     readonly_fields = ['id']
 
 
+class UserRelateTypeAdmin(admin.ModelAdmin):
+    fields = ("id", "relate_key", "relate_name", "description",)
+    list_display = ("id", "relate_key", "relate_name", "description",)
+    readonly_fields = ['id']
+
+
+class UserRelateToUserAdmin(admin.ModelAdmin):
+    fields = ("id", "user", "with_user", "user_relate_type",)
+    list_display = ("id", "user", "with_user", "user_relate_type",)
+    readonly_fields = ['id']
+
+
 admin.site.register(BaseInfo, BaseInfoAdmin)
 admin.site.register(Auth, AuthAdmin)
 admin.site.register(DetailInfo, DetailInfoAdmin)
@@ -127,10 +138,12 @@ admin.site.register(History, HistoryAdmin)
 admin.site.register(RestrictRegion, RestrictRegionAdmin)
 admin.site.register(Platform, PlatformAdmin)
 admin.site.register(PlatformsToUsers, PlatformsToUsersAdmin)
-admin.site.register(Permission, PermissionAdmin)
-admin.site.register(PermissionValue, PermissionValueAdmin)
-admin.site.register(Group, GroupAdmin)
+# admin.site.register(Permission, PermissionAdmin)
+# admin.site.register(PermissionValue, PermissionValueAdmin)
+# admin.site.register(Group, GroupAdmin)
 admin.site.register(ContactBook, ContactBookAdmin)
 admin.site.register(ExtendField, ExtendFieldAdmin)
 admin.site.register(UserSsoServe, UserSsoServeAdmin)
-admin.site.register(UserSsoToUser, UserSsoToUserAdmin)
\ No newline at end of file
+admin.site.register(UserSsoToUser, UserSsoToUserAdmin)
+admin.site.register(UserRelateType, UserRelateTypeAdmin)
+admin.site.register(UserRelateToUser, UserRelateToUserAdmin)
