@@ -8,13 +8,11 @@
 """
 from rest_framework.views import APIView
 
-from xj_role.services.user_group_service import UserGroupService
 from xj_role.services.permission_service import PermissionService
 from ..services.user_service import UserService
 from ..utils.custom_response import util_response
-from ..utils.custom_tool import is_number
-from ..utils.model_handle import parse_data
 from ..utils.j_dict import JDict
+from ..utils.model_handle import parse_data
 
 
 class UserListAPIView(APIView):
@@ -41,39 +39,43 @@ class UserListAPIView(APIView):
                 return util_response(err=1002, msg=error_text)
 
         auth_list = JDict(auth_list)
-        ban_user_list = []
-        allow_user_list = []
-        if auth_list.GROUP_PARENT and auth_list.GROUP_PARENT.ban_view.upper() == "Y":
-            ban_user_list.extend(auth_list.GROUP_PARENT.user_list)
-        else:
-            allow_user_list.extend(auth_list.GROUP_PARENT.user_list if auth_list.GROUP_PARENT else [])
-
-        if auth_list.GROUP_CHILDREN and auth_list.GROUP_CHILDREN.ban_view.upper() == "Y":
-            ban_user_list.extend(auth_list.GROUP_CHILDREN.user_list)
-        else:
-            allow_user_list.extend(auth_list.GROUP_CHILDREN.user_list if auth_list.GROUP_CHILDREN else [])
-
-        if auth_list.GROUP_INSIDE and auth_list.GROUP_INSIDE.ban_view.upper() == "Y":
-            ban_user_list.extend(auth_list.GROUP_INSIDE.user_list)
-        else:
-            allow_user_list.extend(auth_list.GROUP_INSIDE.user_list if auth_list.GROUP_INSIDE else [])
-
-        if not auth_list.GROUP_ADMINISTRATOR and not auth_list.GROUP_MANAGER:
-            if auth_list.GROUP_OUTSIDE and auth_list.GROUP_OUTSIDE.ban_view.upper() == "Y":
-                params['user_id__in'] = allow_user_list  # TODO 待删除
-                params['allow_user_list'] = allow_user_list
-            else:
-                params["user_id__not_in"] = ban_user_list  # TODO 待删除
-                params["ban_user_list"] = ban_user_list
-        else:
-            params["is_admin"] = True
+        # ban_user_list = []
+        # allow_user_list = []
+        # if auth_list.GROUP_PARENT and auth_list.GROUP_PARENT.ban_view.upper() == "Y":
+        #     ban_user_list.extend(auth_list.GROUP_PARENT.user_list)
+        # else:
+        #     allow_user_list.extend(auth_list.GROUP_PARENT.user_list if auth_list.GROUP_PARENT else [])
+        #
+        # if auth_list.GROUP_CHILDREN and auth_list.GROUP_CHILDREN.ban_view.upper() == "Y":
+        #     ban_user_list.extend(auth_list.GROUP_CHILDREN.user_list)
+        # else:
+        #     allow_user_list.extend(auth_list.GROUP_CHILDREN.user_list if auth_list.GROUP_CHILDREN else [])
+        #
+        # if auth_list.GROUP_INSIDE and auth_list.GROUP_INSIDE.ban_view.upper() == "Y":
+        #     ban_user_list.extend(auth_list.GROUP_INSIDE.user_list)
+        # else:
+        #     allow_user_list.extend(auth_list.GROUP_INSIDE.user_list if auth_list.GROUP_INSIDE else [])
+        #
+        # if not auth_list.GROUP_ADMINISTRATOR and not auth_list.GROUP_MANAGER:
+        #     if auth_list.GROUP_OUTSIDE and auth_list.GROUP_OUTSIDE.ban_view.upper() == "Y":
+        #         params['user_id__in'] = allow_user_list  # TODO 待删除
+        #         params['allow_user_list'] = allow_user_list
+        #     else:
+        #         params["user_id__not_in"] = ban_user_list  # TODO 待删除
+        #         params["ban_user_list"] = ban_user_list
+        # else:
+        #     params["is_admin"] = True
         # 分组筛选用户ID
         # user_group_id = params.pop("user_group_id", None)
         # if user_group_id and is_number(user_group_id):
         #     id_list, err = GroupService.get_user_from_group(user_group_id)
         #     params.setdefault("id_list", id_list)
+        try:
+            need_Pagination = int(params.get("need_Pagination", 1))
+        except ValueError:
+            need_Pagination = 1
         # 获取数据
-        data, error_text = UserService.user_list(params,allow_user_list,ban_user_list)
+        data, error_text = UserService.user_list(params, None, None, need_Pagination=need_Pagination)
         if error_text:
             return util_response(err=47767, msg=error_text)
         return util_response(data=data)
