@@ -1,10 +1,14 @@
+from logging import getLogger
+
 from django.core.cache import cache
 from rest_framework import response
 from rest_framework.views import APIView
 
-from ..utils.model_handle import parse_data
 from ..services.user_sms_service import UserSmsService
 from ..utils.custom_response import util_response
+from ..utils.model_handle import parse_data
+
+logger = getLogger('log')
 
 
 class ShortMessageLogin(APIView):
@@ -26,6 +30,7 @@ class ShortMessageLogin(APIView):
             if err == 0:
                 return util_response(data=data)
             else:
+                logger.error('---短信登录错误：' + err + '---')
                 return util_response(msg=err, err=6004)
         else:
             return util_response(err=4002, msg="验证码错误")
