@@ -6,12 +6,16 @@
 """
 
 # 微信登录方法
+from logging import getLogger
+
 from rest_framework.views import APIView
 
 from ..services.wechat_service import WechatService
 from ..utils.custom_response import util_response
 from ..utils.custom_tool import parse_data
 
+logger = getLogger('log')
+
 
 class WechetLogin(APIView):
     # 微信手机号码登录
@@ -28,4 +32,5 @@ class WechetLogin(APIView):
         if err == 0:
             return util_response(data=data)
         else:
+            logger.error('---登录错误：' + err + '---')
             return util_response(msg=err, err=6004)
