@@ -5,70 +5,70 @@ from django.utils import timezone
 # Create your models here.
 
 
-# class Permission(models.Model):
-#     """ 9、User_Permission  权限组表 [1-N] """
-#     permission_id = models.IntegerField(verbose_name='权限ID', primary_key=True, help_text='必填。不自动生成，由运营人员统一设置。')
-#     permission_name = models.CharField(verbose_name='权限名称', max_length=255, blank=True, null=True, help_text='权限名称')
-#
-#     class Meta:
-#         db_table = 'user_permission'
-#         verbose_name_plural = "09. 用户 - 权限组表"
-#
-#     def __str__(self):
-#         # return f"{self.user_name}({self.full_name})"
-#         return f"{self.permission_name}"
+class Permission(models.Model):
+    """ 9、User_Permission  权限组表 [1-N] """
+    permission_id = models.IntegerField(verbose_name='权限ID', primary_key=True, help_text='必填。不自动生成，由运营人员统一设置。')
+    permission_name = models.CharField(verbose_name='权限名称', max_length=255, blank=True, null=True, help_text='权限名称')
+
+    class Meta:
+        db_table = 'user_permission'
+        verbose_name_plural = "09. 用户 - 权限组表"
+
+    def __str__(self):
+        # return f"{self.user_name}({self.full_name})"
+        return f"{self.permission_name}"
 
 
-# class PermissionValue(models.Model):
-#     """
-#     10、User_Permission_Value 权限组值表 [1-N]
-#     权限标识值，一个permission_id可以对应多个value，多值形成一组权限。值为宏名，需要多语言翻译
-#     """
-#     permission = models.ForeignKey(Permission, verbose_name='权限ID', on_delete=models.DO_NOTHING, help_text='')
-#     module = models.CharField(verbose_name='模型名称', max_length=255, blank=True, null=True, help_text='')
-#     feature = models.CharField(verbose_name='功能专注点', max_length=255, blank=True, null=True,
-#                                help_text='group: 按用户组给权限, route: 按路由给权限, point: 按交互点给权限, ..., category: 类别权限')
-#     permission_value = models.CharField(verbose_name='权限标识值', max_length=255, blank=True, null=True,
-#                                         help_text='权限标识值，一个permission_id可以对应多个value，多值形成一组权限。值为宏名，需要多语言翻译')
-#     type = models.CharField(verbose_name='类型', max_length=255, blank=True, null=True, help_text='暂不使用')
-#     relate_value = models.CharField(verbose_name='权限内容关联值', max_length=255, blank=True, null=True, help_text='')
-#     config = models.JSONField(verbose_name='权限更多配置', max_length=255, blank=True, null=True, help_text='权限更多配置，常用于前端路由')
-#     is_enable = models.CharField(verbose_name='是否启用权限', max_length=1, blank=True, null=True, help_text='')
-#     is_system = models.CharField(verbose_name='是否系统权限', max_length=1, blank=True, null=True,
-#                                  help_text='是否系统权限，系统权限不可以删除，默认SUPER_ADMINISTRATOR的所有value都是系统权限。')
-#     is_ban = models.CharField(verbose_name='是否禁用', max_length=1, blank=True, null=True,
-#                               help_text='是否全部禁用该权限，Y禁用，N允许，默认N。使用减法原则，约定无权限值则视为允许。')
-#     ban_view = models.CharField(verbose_name='是否可看', max_length=1, blank=True, null=True, help_text='')
-#     ban_edit = models.CharField(verbose_name='是否编辑', max_length=1, blank=True, null=True, help_text='')
-#     ban_add = models.CharField(verbose_name='是否插入', max_length=1, blank=True, null=True, help_text='')
-#     ban_delete = models.CharField(verbose_name='是否删除', max_length=1, blank=True, null=True, help_text='')
-#     description = models.CharField(verbose_name='权限值', max_length=1, blank=True, null=True, help_text='')
-#     permission_code = models.BooleanField(verbose_name='是否系统权限', blank=True, null=True, help_text='')
-#
-#     class Meta:
-#         db_table = 'user_permission_value'
-#         verbose_name_plural = "10. 用户 - 权限组值表"
-#
-#     def __str__(self):
-#         # return f"{self.user_name}({self.full_name})"
-#         return f"{self.permission_value}"
+class PermissionValue(models.Model):
+    """
+    10、User_Permission_Value 权限组值表 [1-N]
+    权限标识值，一个permission_id可以对应多个value，多值形成一组权限。值为宏名，需要多语言翻译
+    """
+    permission = models.ForeignKey(Permission, verbose_name='权限ID', on_delete=models.DO_NOTHING, help_text='')
+    module = models.CharField(verbose_name='模型名称', max_length=255, blank=True, null=True, help_text='')
+    feature = models.CharField(verbose_name='功能专注点', max_length=255, blank=True, null=True,
+                               help_text='group: 按用户组给权限, route: 按路由给权限, point: 按交互点给权限, ..., category: 类别权限')
+    permission_value = models.CharField(verbose_name='权限标识值', max_length=255, blank=True, null=True,
+                                        help_text='权限标识值，一个permission_id可以对应多个value，多值形成一组权限。值为宏名，需要多语言翻译')
+    type = models.CharField(verbose_name='类型', max_length=255, blank=True, null=True, help_text='暂不使用')
+    relate_value = models.CharField(verbose_name='权限内容关联值', max_length=255, blank=True, null=True, help_text='')
+    config = models.JSONField(verbose_name='权限更多配置', max_length=255, blank=True, null=True, help_text='权限更多配置，常用于前端路由')
+    is_enable = models.CharField(verbose_name='是否启用权限', max_length=1, blank=True, null=True, help_text='')
+    is_system = models.CharField(verbose_name='是否系统权限', max_length=1, blank=True, null=True,
+                                 help_text='是否系统权限，系统权限不可以删除，默认SUPER_ADMINISTRATOR的所有value都是系统权限。')
+    is_ban = models.CharField(verbose_name='是否禁用', max_length=1, blank=True, null=True,
+                              help_text='是否全部禁用该权限，Y禁用，N允许，默认N。使用减法原则，约定无权限值则视为允许。')
+    ban_view = models.CharField(verbose_name='是否可看', max_length=1, blank=True, null=True, help_text='')
+    ban_edit = models.CharField(verbose_name='是否编辑', max_length=1, blank=True, null=True, help_text='')
+    ban_add = models.CharField(verbose_name='是否插入', max_length=1, blank=True, null=True, help_text='')
+    ban_delete = models.CharField(verbose_name='是否删除', max_length=1, blank=True, null=True, help_text='')
+    description = models.CharField(verbose_name='权限值', max_length=1, blank=True, null=True, help_text='')
+    permission_code = models.BooleanField(verbose_name='是否系统权限', blank=True, null=True, help_text='')
+
+    class Meta:
+        db_table = 'user_permission_value'
+        verbose_name_plural = "10. 用户 - 权限组值表"
+
+    def __str__(self):
+        # return f"{self.user_name}({self.full_name})"
+        return f"{self.permission_value}"
 
 
-# class Group(models.Model):
-#     """ 11、User_Group 分组表 """
-#     id = models.AutoField(verbose_name='ID', primary_key=True)
-#     group = models.CharField(verbose_name='用户组', max_length=32, blank=True, null=True, help_text='')
-#     parent_group = models.CharField(verbose_name='父组', max_length=32, blank=True, null=True, help_text='')
-#     permission = models.ForeignKey(Permission, verbose_name='权限ID', on_delete=models.DO_NOTHING, blank=True, null=True,
-#                                    help_text='')
-#     description = models.CharField(verbose_name='描述', max_length=32, blank=True, null=True, help_text='')
-#
-#     class Meta:
-#         db_table = 'user_group'
-#         verbose_name_plural = "11. 用户 - 分组表"
-#
-#     def __str__(self):
-#         return f"{self.description}"
+class Group(models.Model):
+    """ 11、User_Group 分组表 """
+    id = models.AutoField(verbose_name='ID', primary_key=True)
+    group = models.CharField(verbose_name='用户组', max_length=32, blank=True, null=True, help_text='')
+    parent_group = models.CharField(verbose_name='父组', max_length=32, blank=True, null=True, help_text='')
+    permission = models.ForeignKey(Permission, verbose_name='权限ID', on_delete=models.DO_NOTHING, blank=True, null=True,
+                                   help_text='')
+    description = models.CharField(verbose_name='描述', max_length=32, blank=True, null=True, help_text='')
+
+    class Meta:
+        db_table = 'user_group'
+        verbose_name_plural = "11. 用户 - 分组表"
+
+    def __str__(self):
+        return f"{self.description}"
 
 
 class BaseInfo(models.Model):
@@ -87,8 +87,6 @@ class BaseInfo(models.Model):
     wechat_openid = models.CharField(verbose_name='微信开放号', max_length=128, unique=True, blank=True, null=True,
                                      db_index=True, help_text='微信用户开放ID，注意openid是微信的专用名词')
     user_info = models.JSONField(verbose_name='用户信息', blank=True, null=True, help_text='用户扩展信息')
-    # user_group = models.ForeignKey(Group, verbose_name='用户分组', blank=True, null=True, on_delete=models.DO_NOTHING, help_text='')
-    # permission = models.ForeignKey(Permission, verbose_name='用户权限', blank=True, null=True, on_delete=models.DO_NOTHING, help_text='')
     register_time = models.DateTimeField(verbose_name='注册时间', default=timezone.now, help_text='')
 
     class Meta:
@@ -265,7 +263,7 @@ class Platform(models.Model):
     """ 8、*User_Platform 平台表 """
     platform_id = models.IntegerField(verbose_name='平台ID', primary_key=True, help_text='必填。不自动生成，由运营人员统一设置。')
     platform_name = models.CharField(verbose_name='平台名称', max_length=128, help_text='必填。平台名称可以是中文、英文、俄文等。')
-    platforms_to_users = models.ManyToManyField(BaseInfo, through='PlatformsToUsers', help_text='平台用户多对多')
+    platform_code = models.CharField(verbose_name='平台编码', max_length=8, help_text='必填。自动生成8为随机编码')
 
     class Meta:
         db_table = 'user_platform'
@@ -280,8 +278,7 @@ class Platform(models.Model):
 
 class PlatformsToUsers(models.Model):
     """ 9、*User_Platforms_To_Users - 多对多平台记录表 [N-N] """
-    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, db_column='user_id',
-                             help_text='')
+    user = models.ForeignKey(BaseInfo, verbose_name='用户', on_delete=models.DO_NOTHING, db_column='user_id', help_text='')
     platform = models.ForeignKey(Platform, verbose_name='平台', on_delete=models.DO_NOTHING, help_text='')
     platform_user_id = models.BigIntegerField(verbose_name='平台用户ID', blank=True, null=True, db_index=True, help_text='')
 
