@@ -8,10 +8,8 @@
 """
 from django.core.paginator import Paginator
 from django.db.models import F
-from rest_framework import status
 
 from ..models import ExtendField, DetailInfo, BaseInfo
-from ..utils.custom_response import util_response
 from ..utils.custom_tool import *
 
 
@@ -58,7 +56,7 @@ class DetailInfoService:
                 list_set = DetailInfo.objects.filter(**transformed_dict)
                 count = DetailInfo.objects.filter(**transformed_dict).count()
             except Exception as e:
-                return util_response("", 7557, status.HTTP_400_BAD_REQUEST, e.__str__())
+                return None, e.__str__()
             # 分页数据
             page_set = list(Paginator(list_set.values(), limit).page(page))
             res_data = filter_result_field(
@@ -80,6 +78,11 @@ class DetailInfoService:
 
     @staticmethod
     def get_detail(user_id):
+        """
+        获取当前用户的基础信息和详细信息集合
+        :param user_id:
+        :return: detail_info,err_msg
+        """
         user_base = BaseInfo.objects.filter(id=user_id).first()
         if not user_base:
             return None, '用户不存在'
@@ -96,7 +99,8 @@ class DetailInfoService:
             .annotate(email=F("user__email")) \
             .annotate(register_time=F("user__register_time")) \
             .values().first()
-        if not user_detail:
+
+        if not user_detail:  # 当前用户没有填写详细信息的时候
             # 默认空字段返回
             user_base_info_fields = user_base_info.keys()
             for i in model_fields:
@@ -110,7 +114,7 @@ class DetailInfoService:
                 param_dict=user_base_info,
                 alias_dict={"user": "user_id"}
             ), None
-        else:
+        else:  # 当前用户填写过详细信息
             # 扩展字段转换
             alias_dict = format_params_handle(
                 param_dict=user_detail,
@@ -125,11 +129,16 @@ class DetailInfoService:
 
     @staticmethod
     def create_or_update_detail(params):
+        """
+        添加或者更新用户的详细信息
+        :param params: 添加/修改参数
+        :return: None,err_msg
+        """
         # 参数判断
         user_id = params.pop('user_id', None)
-        detail_id = params.pop('id', None)
         if not user_id or not params:
-            return util_response(err=1000, msg="参数错误")
+            return None, "参数错误"
+
         # 判断用户是否存在
         user_base = BaseInfo.objects.filter(id=user_id)
         user_base_info = user_base.first()
@@ -141,15 +150,15 @@ class DetailInfoService:
         #     user_base.update(nickname=nickname)
 
         # 扩展字段处理，还原
-        field_dict = {item['field']: item['field_index'] for item in ExtendField.objects.all().values("field", 'field_index')}
-        model_fields = [i.name for i in DetailInfo._meta.fields] + list(field_dict.values())
+        alias_dict = {item['field']: item['field_index'] for item in ExtendField.objects.all().values("field", 'field_index')}
+        filter_filed_list = [i.name for i in DetailInfo._meta.fields] + list(alias_dict.values())
         alias_params = format_params_handle(
             param_dict=params,
-            alias_dict=field_dict
+            alias_dict=alias_dict
         )
         transformed_params = format_params_handle(
             param_dict=alias_params,
-            filter_filed_list=model_fields
+            filter_filed_list=filter_filed_list
         )
         transformed_params.setdefault("user_id", user_id)
         # 进行数据库操作
