@@ -17,9 +17,10 @@ from rest_framework import serializers
 
 from config.config import JConfig as MainConfig
 from main.settings import BASE_DIR
+from xj_user.services.user_detail_info_service import DetailInfoService
 from ..models import Auth, DetailInfo, ExtendField, Platform
 from ..models import BaseInfo
-from ..utils.custom_tool import filter_result_field
+from ..utils.custom_tool import filter_result_field, format_params_handle, format_list_handle
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
 
@@ -195,8 +196,7 @@ class UserService:
         expire_timestamp = datetime.utcnow() + timedelta(days=7, seconds=0)
         # 为本次登录生成Token并记录
         # todo 漏洞，当用户修改用户名时，并可能导致account失效，是否存用户ID更好
-        token = jwt.encode(payload={'account': phone, 'user_id': user_id, "exp": expire_timestamp},
-                           key=jwt_secret_key)
+        token = jwt.encode(payload={'account': phone, 'user_id': user_id, "exp": expire_timestamp}, key=jwt_secret_key)
         # payload = jwt.decode(token, key=Config.getIns().get('xj_user', 'JWT_SECRET_KEY'), verify=True, algorithms=["RS256", "HS256"])
         # print("> payload:", payload)
         auth_set.token = token
@@ -221,8 +221,7 @@ class UserService:
                                                          seconds=int(expire_second))
         # 为本次登录生成Token并记录
         # todo 漏洞，当用户修改用户名时，并可能导致account失效，是否存用户ID更好
-        token = jwt.encode(payload={'account': phone, 'user_id': user_id, "exp": expire_timestamp},
-                           key=jwt_secret_key)
+        token = jwt.encode(payload={'account': phone, 'user_id': user_id, "exp": expire_timestamp}, key=jwt_secret_key)
         # payload = jwt.decode(token, key=Config.getIns().get('xj_user', 'JWT_SECRET_KEY'), verify=True, algorithms=["RS256", "HS256"])
         # print("> payload:", payload)
         auth_set.token = token
@@ -284,7 +283,9 @@ class UserService:
 
     # 用户信息列表
     @staticmethod
-    def user_list(params={}, allow_user_list=None, ban_user_list=None):
+    def user_list(params=None, allow_user_list=None, ban_user_list=None, need_Pagination=True):
+        if params is None:
+            params = {}
         user_base_set = BaseInfo.objects
         # 需要分页的时候
         page = params.get("page", 1)
@@ -317,10 +318,7 @@ class UserService:
                 user_base_set = user_base_set.filter(full_name__icontains=full_name)
             if nickname:
                 user_base_set = user_base_set.filter(user_name__icontains=nickname)
-            # print(user_base_set.query)
 
-            # user_base_set = BaseInfo.objects.filter(**params).annotate(user_id=F("id"))
-            count = user_base_set.count()
             user_base_set = user_base_set.values(
                 "user_id",
                 "email",
@@ -328,12 +326,13 @@ class UserService:
                 "user_name",
                 "nickname",
                 "phone",
-                "register_time"
-                # "permission_id",
-                # "user_group_id",  # TODO 该功能已经移动到了角色模块 计划删除
-                # "wechat_openid",
+                "register_time",
+                "wechat_openid",
             )
-
+            count = user_base_set.count()
+            # 查询保护，当超过100条的时候则需要分页查询
+            if not need_Pagination and count <= 100:
+                return list(user_base_set), None
         except Exception as e:
             return None, "err:" + e.__str__()
         page_set = Paginator(user_base_set, size).page(page)
@@ -342,6 +341,56 @@ class UserService:
             page_list = list(page_set.object_list)
         return {'size': int(size), 'page': int(page), 'count': count, 'list': page_list}, None
 
+    @staticmethod
+    def user_search(user_id_list: list = None, search_params: dict = None, need_map: bool = False, filter_fields: list = None):
+        """
+        搜索用户，返回用户基础信息。服务调用不做接口
+        :param user_id_list: 用户id列表
+        :param search_params: 搜素字段
+        :param need_map: 是否需要映射
+        :param filter_fields: 需要查询的字段
+        :return: data, err
+        """
+        if not user_id_list and not search_params:
+            return [], "参数错误,无法筛选数据"
+
+        # 列表的查询参数处理
+        if filter_fields is None:
+            filter_fields = ["id", "user_name", "full_name", "nickname", "phone", "email", "register_time"]
+        else:
+            filter_fields = format_list_handle(
+                param_list=filter_fields,
+                filter_filed_list=["id", "user_name", "full_name", "nickname", "phone", "email", "register_time"]
+            )
+            filter_fields = ["id", "user_name", "full_name", "nickname", "phone", "email", "register_time"] if not filter_fields else filter_fields
+        # 字段查询参数处理
+        if search_params:
+            search_params = format_params_handle(
+                param_dict=search_params,
+                filter_filed_list=["id", "user_id", "user_name", "full_name", "nickname", "phone", "email", "register_time", "register_time_start", "register_time_end"],
+                alias_dict={"user_id": "id", "register_time_start": "register_time__gte", "register_time_end": "register_time_lte"}
+            )
+
+        # 查询管理
+        try:
+            # orm 查询
+            if user_id_list:
+                user_base_set = BaseInfo.objects.filter(id__in=user_id_list)
+            else:
+                user_base_set = BaseInfo.objects.filter(**search_params)
+            user_base_set = user_base_set.values(*filter_fields)
+            # 获取列表并字段转换，id ==>> user_id
+            user_base_list = filter_result_field(
+                result_list=list(user_base_set),
+                alias_dict={"id": "user_id"}
+            )
+            # 如果需要转换，则进行映射
+            if need_map:
+                user_base_list = {i['user_id']: i for i in user_base_list}
+            return user_base_list, None
+        except Exception as e:
+            return [], "err:" + str(e)
+
     @staticmethod
     def user_add(params):
         # 添加逻辑
@@ -535,6 +584,55 @@ class UserService:
         except:
             return None, "未知错误"
 
+    @staticmethod
+    def user_edit_v2(params=None, user_id=None):
+        """
+        用户修改服务。
+        PS：原本的代码逻辑复杂，而且不规范，为了大面积的受影响，开发二版本。
+        :param params: 修改参数集合
+        :param user_id: 用户ID
+        :return: None,err_msg
+        """
+        if params is None:
+            params = {}
+        if not user_id:
+            return None, "用户ID不存在"
+
+        # 绑定信息验重
+        email_other_user = BaseInfo.objects.exclude(id=user_id).filter(email=params.get("email", None)).first()
+        if params.get("email") and email_other_user:
+            return None, "当前邮箱被绑定"
+        phone_other_user = BaseInfo.objects.exclude(id=user_id).filter(phone=params.get("phone", None)).first()
+        if params.get("phone") and phone_other_user:
+            return None, "当前手机号被绑定"
+
+        # 用户基础信息中仅仅可以修改一下参数
+        # PS:邮箱和手机号不能为空，所以需要user_name不可修改，而且最初登录使用user_name。然后可以绑定
+        base_info_params = format_params_handle(
+            param_dict=params.copy(),
+            filter_filed_list=["full_name", "nickname", "user_info", "email", "phone"],
+            is_remove_null=True
+        )
+        # 更新基础信息
+        base_query_set = BaseInfo.objects.filter(id=user_id)
+        if not base_query_set.first():
+            return None, "用户不存在"
+        try:
+            base_query_set.update(**base_info_params)
+        except Exception as e:
+            return None, "修改异常：" + str(e)
+
+        # 详细信息
+        detail_info_params = format_params_handle(
+            param_dict=params.copy(),
+            remove_filed_list=["full_name", "nickname", "user_info"]
+        )
+        detail_info_params.setdefault("user_id", user_id)
+        data, err = DetailInfoService.create_or_update_detail(detail_info_params)
+        if err:
+            return None, err
+        return None, None
+
     @staticmethod
     def user_role_edit(params):
         # 修改逻辑 TODO 为什么起这个名字，这个不是用户基础信息修改吗 BaseInfo.objects.filter(id=user_id).update(**base_info)
