@@ -7,6 +7,8 @@
 @created_time: 2022/7/7 9:38
 """
 from datetime import datetime, timedelta
+import json
+from logging import getLogger
 from pathlib import Path
 
 from django.contrib.auth.hashers import make_password
@@ -14,10 +16,10 @@ import jwt
 import requests
 
 from main.settings import BASE_DIR
-from xj_role.services.role_service import RoleService
-from ..models import BaseInfo, Auth, UserSsoToUser, UserRelateToUser
+from ..models import BaseInfo, Auth, UserSsoToUser
 from ..services.user_detail_info_service import DetailInfoService
 from ..services.user_relate_service import UserRelateToUserService
+from ..utils.custom_tool import get_short_id
 from ..utils.j_config import JConfig
 from ..utils.j_dict import JDict
 from ..utils.model_handle import parse_model
@@ -41,6 +43,8 @@ jwt_secret_key = main_config_dict.jwt_secret_key or module_config_dict.jwt_secre
 expire_day = main_config_dict.expire_day or module_config_dict.expire_day or ""
 expire_second = main_config_dict.expire_second or module_config_dict.expire_second or ""
 
+logger = getLogger('log')
+
 
 class UserSmsService:
 
@@ -79,7 +83,7 @@ class UserSmsService:
         if not current_user:
             # 进行注册用户基础信息
             base_info = {
-                'user_name': '',
+                'user_name': get_short_id(8),
                 'nickname': gen_one_word_digit(),
                 'phone': phone,
                 'email': '',
@@ -93,9 +97,11 @@ class UserSmsService:
             # 用户第一次登录即注册，允许添加用户的详细信息
             try:
                 detail_params.setdefault("user_id", current_user.get('id', None))
-                data, err = DetailInfoService.create_or_update_detail(detail_params)
+                data, detail_err = DetailInfoService.create_or_update_detail(detail_params)
+                if detail_err:
+                    raise Exception(detail_err)
             except Exception as e:
-                pass
+                logger.error('---首次登录写入用户详细信息异常：' + str(e) + '---')
 
             # 进行单点登录相关操作
             if sso_serve_id:
@@ -146,54 +152,14 @@ class UserSmsService:
             ).order_by('-update_time').first()
 
         # 绑定用户关系 邀请关系和收益关系
-        print("执行绑定用户关系")
-        try:
-            print("detail_params:", detail_params)
-            print("user_id", current_user.get('id', None))
-            inviter_id = detail_params.get("inviter_id")
-            if not inviter_id:
-                raise Exception("没有传递邀请人ID无法绑定邀请人")
-
-            # 判断是否是一个有效的用户ID-->>> 有效则之际昂顶邀请人关系
-            inviter = BaseInfo.objects.filter(id=inviter_id).first()
-            if not inviter:
-                raise Exception("没有该用户")
-            data, err = UserRelateToUserService.add(
-                {
-                    "user_id": current_user.get('id', None),
-                    "with_user_id": inviter_id,
-                    "user_relate_type_id": 1
-                }
+        data, relate_err = UserRelateToUserService.bind_bxtx_relate(params=detail_params, user_info=current_user)
+        if relate_err:
+            logger.error(
+                '绑定用户关系异常：' + str(relate_err) +
+                ' \n当前用户ID:' + str(current_user.get("id", "")) +
+                '\n detail_params:' + json.dumps(detail_params)
             )
-            if err:
-                raise Exception(err)
 
-            # 查询邀请人的受益人是谁，如果存在，直接绑定。
-            saler = UserRelateToUser.objects.filter(user_id=inviter_id, user_relate_type_id=2).first()
-            if saler:
-                data, err = UserRelateToUserService.add(
-                    {
-                        "user_id": current_user.get('id', None),
-                        "with_user_id": inviter_id,
-                        "user_relate_type_id": 2
-                    }
-                )
-                raise Exception("ok")
-
-            # 邀请人不存在受益人，如果是业务则受益人也是邀请人
-            res, err = RoleService.is_this_role(user_id=inviter_id, role_key="BID-SALESMAN")  # 如果是业务人员
-            if res:
-                data, err = UserRelateToUserService.add(
-                    {
-                        "user_id": current_user.get('id', None),
-                        "with_user_id": inviter_id,
-                        "user_relate_type_id": 2
-                    }
-                )
-                raise Exception("ok")
-        except Exception as e:
-            print("e:", e)
-            pass
         return 0, {'token': auth_set.token, 'user_info': current_user}
 
     def __set_token(self, user_id, account):
