@@ -30,7 +30,11 @@ app_name = 'xj_user'
 
 # 应用路由
 urlpatterns = [
+    # 平台相关API
     re_path(r'^platform/?$', user_platform.UserPlatform.as_view(), ),
+    re_path(r'^platform_list/?$', user_platform.UserPlatform.list, ),
+    re_path(r'^get_user_platform/?$', user_platform.UserPlatform.get_user_platform),  # 获取当前用户的平台信息
+
     re_path(r'^register/?$', user_register.UserRegister.as_view(), ),
     re_path(r'^login/?$', user_login.UserLogin.as_view(), ),
     re_path(r'^login_wechat/?$', user_login_wechat.WechetLogin.as_view(), ),
@@ -38,6 +42,7 @@ urlpatterns = [
     re_path(r'^list/?$', user_list.UserListAPIView.as_view(), ),  # 用户列表
     re_path(r'^info/?$', user_info.UserInfo.as_view(), ),
     re_path(r'^edit/?$', user_edit.UserEdit.as_view(), ),
+    re_path(r'^edit_v2/?$', user_edit.UserEdit.user_edit_v2, ),
     re_path(r'^add/?$', user_add.UserAdd.as_view(), ),  # 管理员添加用户
     re_path(r'^delete/?$', user_edit.UserEdit.as_view(), ),  # 管理员添加用户
 
@@ -58,16 +63,12 @@ urlpatterns = [
 
     # re_path(r'^send_message/?$', user_short_message.UserShortMessage.as_view(), ),
     # re_path(r'^login_short_message/?$', user_login_short_message.ShortMessageLogin.as_view(), ),
+
     re_path(r'^login_short_message/?$', user_login_short_message.ShortMessageLogin.sms_login),
-
     re_path(r'^login/?$', user_login.UserLogin.as_view(), ),
-
     re_path(r'^sso_serve/?$', user_sso_serve.UserSsoServe.as_view(), ),
-
     re_path(r'^statistics/?$', user_statistics.UserStatisticsAPI.as_view(), ),
-
     # 用户关系相关接口
     re_path(r'^relate_type/?$', user_relate_apis.UserRelateTypeApis.as_view(), ),
     re_path(r'^relate_user/?$', user_relate_apis.UserRelateToUserApis.as_view(), ),
-
 ]
