@@ -33,7 +33,7 @@ def user_authentication_wrapper(func):
             return func(instance * args, request=request, request_params={}, **kwargs, )
         # token = request.META.get('HTTP_AUTHORIZATION', None)
         token = request.headers.get('Authorization', None)
-        print("> user_authentication_wrapper token:", token, type(token))
+        # print("> user_authentication_wrapper token:", token, type(token))
 
         # 如果没有传token则可视为以游客身份访问
         if not token or str(token) == 'null' or str(token).strip().upper() == "BEARER":
@@ -78,7 +78,7 @@ def user_authentication_force_wrapper(func):
 
         # 如果没有传token则可视为以游客身份访问
         if not token or str(token) == 'null' or str(token).strip().upper() == "BEARER":
-            print("token:", token)
+            # print("token:", token)
             return JsonResponse({'err': 6000, 'msg': '该用户未登录'})
 
         user_serv, error_text = UserService.check_token(token)
